@@ -25,10 +25,12 @@ import oslo_messaging as messaging
 from ironic.common import exception
 from ironic.common import hash_ring
 from ironic.common.i18n import _
+from ironic.common.json_rpc import client as json_rpc
 from ironic.common import release_mappings as versions
 from ironic.common import rpc
 from ironic.conductor import manager
 from ironic.conf import CONF
+from ironic.db import api as dbapi
 from ironic.objects import base as objects_base
 
 
@@ -96,13 +98,14 @@ class ConductorAPI(object):
     |    1.45 - Added continue_node_deploy
     |    1.46 - Added reset_interfaces to update_node
     |    1.47 - Added support for conductor groups
+    |    1.48 - Added allocation API
 
     """
 
     # NOTE(rloo): This must be in sync with manager.ConductorManager's.
     # NOTE(pas-ha): This also must be in sync with
     #               ironic.common.release_mappings.RELEASE_MAPPING['master']
-    RPC_API_VERSION = '1.47'
+    RPC_API_VERSION = '1.48'
 
     def __init__(self, topic=None):
         super(ConductorAPI, self).__init__()
@@ -110,14 +113,19 @@ class ConductorAPI(object):
         if self.topic is None:
             self.topic = manager.MANAGER_TOPIC
 
-        target = messaging.Target(topic=self.topic,
-                                  version='1.0')
         serializer = objects_base.IronicObjectSerializer()
         release_ver = versions.RELEASE_MAPPING.get(CONF.pin_release_version)
         version_cap = (release_ver['rpc'] if release_ver
                        else self.RPC_API_VERSION)
-        self.client = rpc.get_client(target, version_cap=version_cap,
-                                     serializer=serializer)
+
+        if CONF.rpc_transport == 'json-rpc':
+            self.client = json_rpc.Client(serializer=serializer,
+                                          version_cap=version_cap)
+            self.topic = ''
+        else:
+            target = messaging.Target(topic=self.topic, version='1.0')
+            self.client = rpc.get_client(target, version_cap=version_cap,
+                                         serializer=serializer)
 
         use_groups = self.client.can_send_version('1.47')
         # NOTE(deva): this is going to be buggy
@@ -154,6 +162,16 @@ class ConductorAPI(object):
         hostname = self.get_conductor_for(node)
         return '%s.%s' % (self.topic, hostname)
 
+    def get_random_topic(self):
+        """Get an RPC topic for a random conductor service."""
+        conductors = dbapi.get_instance().get_online_conductors()
+        try:
+            hostname = random.choice(conductors)
+        except IndexError:
+            # There are no conductors - return 503 Service Unavailable
+            raise exception.TemporaryFailure()
+        return '%s.%s' % (self.topic, hostname)
+
     def get_topic_for_driver(self, driver_name):
         """Get RPC topic name for a conductor supporting the given driver.
 
@@ -1094,3 +1112,25 @@ class ConductorAPI(object):
         cctxt = self.client.prepare(topic=topic or self.topic, version='1.44')
         return cctxt.call(context, 'remove_node_traits', node_id=node_id,
                           traits=traits)
+
+    def create_allocation(self, context, allocation, topic=None):
+        """Create an allocation.
+
+        :param context: request context.
+        :param allocation: an allocation object.
+        :param topic: RPC topic. Defaults to self.topic.
+        """
+        cctxt = self.client.prepare(topic=topic or self.topic, version='1.48')
+        return cctxt.call(context, 'create_allocation', allocation=allocation)
+
+    def destroy_allocation(self, context, allocation, topic=None):
+        """Delete an allocation.
+
+        :param context: request context.
+        :param allocation: an allocation object.
+        :param topic: RPC topic. Defaults to self.topic.
+        :raises: InvalidState if the associated node is in the wrong provision
+            state to perform deallocation.
+        """
+        cctxt = self.client.prepare(topic=topic or self.topic, version='1.48')
+        return cctxt.call(context, 'destroy_allocation', allocation=allocation)
