@@ -16,11 +16,13 @@ iLO Driver for managing HP Proliant Gen8 and above servers.
 """
 
 from ironic.drivers import generic
+from ironic.drivers.modules.ilo import bios
 from ironic.drivers.modules.ilo import boot
 from ironic.drivers.modules.ilo import console
 from ironic.drivers.modules.ilo import inspect
 from ironic.drivers.modules.ilo import management
 from ironic.drivers.modules.ilo import power
+from ironic.drivers.modules.ilo import raid
 from ironic.drivers.modules.ilo import vendor
 from ironic.drivers.modules import inspector
 from ironic.drivers.modules import noop
@@ -38,6 +40,11 @@ class IloHardware(generic.GenericHardware):
         """List of supported boot interfaces."""
         return [boot.IloVirtualMediaBoot, boot.IloPXEBoot]
 
+    @property
+    def supported_bios_interfaces(self):
+        """List of supported bios interfaces."""
+        return [bios.IloBIOS, noop.NoBIOS]
+
     @property
     def supported_console_interfaces(self):
         """List of supported console interfaces."""
@@ -63,3 +70,15 @@ class IloHardware(generic.GenericHardware):
     def supported_vendor_interfaces(self):
         """List of supported power interfaces."""
         return [vendor.VendorPassthru, noop.NoVendor]
+
+
+class Ilo5Hardware(IloHardware):
+    """iLO5 hardware type.
+
+    iLO5 hardware type is targeted for iLO5 based Proliant Gen10 servers.
+    """
+
+    @property
+    def supported_raid_interfaces(self):
+        """List of supported raid interfaces."""
+        return [raid.Ilo5RAID, noop.NoRAID]
