@@ -15,6 +15,7 @@ from oslo_log import log
 
 from ironic.common import exception
 from ironic.common.i18n import _
+from ironic.common import pxe_utils as common_pxe_utils
 from ironic.drivers import base
 
 CONF = cfg.CONF
@@ -35,10 +36,11 @@ class ExternalStorage(base.StorageInterface):
             raise exception(msg)
 
         if (not self.should_write_image(task)
-            and not CONF.pxe.ipxe_enabled):
+            and not common_pxe_utils.is_ipxe_enabled(task)):
                 msg = _("The [pxe]/ipxe_enabled option must "
                         "be set to True to support network "
-                        "booting to an iSCSI volume.")
+                        "booting to an iSCSI volume or the boot "
+                        "interface must be set to ``ipxe``.")
                 _fail_validation(task, msg)
 
     def get_properties(self):
