@@ -16,14 +16,19 @@ import json
 
 import mock
 import requests
+import retrying
 import six
 from six.moves import http_client
 
 from ironic.common import exception
+from ironic import conf
 from ironic.drivers.modules import agent_client
 from ironic.tests import base
 
 
+CONF = conf.CONF
+
+
 class MockResponse(object):
     def __init__(self, text, status_code=http_client.OK):
         assert isinstance(text, six.string_types)
@@ -96,7 +101,8 @@ class TestAgentClient(base.TestCase):
         self.client.session.post.assert_called_once_with(
             url,
             data=body,
-            params={'wait': 'false'})
+            params={'wait': 'false'},
+            timeout=60)
 
     def test__command_fail_json(self):
         response_text = 'this be not json matey!'
@@ -114,7 +120,8 @@ class TestAgentClient(base.TestCase):
         self.client.session.post.assert_called_once_with(
             url,
             data=body,
-            params={'wait': 'false'})
+            params={'wait': 'false'},
+            timeout=60)
 
     def test__command_fail_post(self):
         error = 'Boom'
@@ -133,6 +140,24 @@ class TestAgentClient(base.TestCase):
                          {'method': method, 'node': self.node.uuid,
                           'error': error}, str(e))
 
+    def test__command_fail_connect(self):
+        error = 'Boom'
+        self.client.session.post.side_effect = requests.ConnectionError(error)
+        method = 'foo.bar'
+        params = {}
+
+        self.client._get_command_url(self.node)
+        self.client._get_command_body(method, params)
+
+        e = self.assertRaises(exception.AgentConnectionFailed,
+                              self.client._command,
+                              self.node, method, params)
+        self.assertEqual('Connection to agent failed: Failed to connect to '
+                         'the agent running on node %(node)s for invoking '
+                         'command %(method)s. Error: %(error)s' %
+                         {'method': method, 'node': self.node.uuid,
+                          'error': error}, str(e))
+
     def test__command_error_code(self):
         response_text = '{"faultstring": "you dun goofd"}'
         self.client.session.post.return_value = MockResponse(
@@ -150,7 +175,8 @@ class TestAgentClient(base.TestCase):
         self.client.session.post.assert_called_once_with(
             url,
             data=body,
-            params={'wait': 'false'})
+            params={'wait': 'false'},
+            timeout=60)
 
     def test_get_commands_status(self):
         with mock.patch.object(self.client.session, 'get',
@@ -159,6 +185,12 @@ class TestAgentClient(base.TestCase):
             res.json.return_value = {'commands': []}
             mock_get.return_value = res
             self.assertEqual([], self.client.get_commands_status(self.node))
+            agent_url = self.node.driver_internal_info.get('agent_url')
+            mock_get.assert_called_once_with(
+                '%(agent_url)s/%(api_version)s/commands' % {
+                    'agent_url': agent_url,
+                    'api_version': CONF.agent.agent_api_version},
+                timeout=CONF.agent.command_timeout)
 
     def test_prepare_image(self):
         self.client._command = mock.MagicMock(spec_set=[])
@@ -229,19 +261,29 @@ class TestAgentClient(base.TestCase):
             node=self.node, method='iscsi.start_iscsi_target',
             params=params, wait=True)
 
-    def test_install_bootloader(self):
+    def _test_install_bootloader(self, root_uuid, efi_system_part_uuid=None,
+                                 prep_boot_part_uuid=None):
         self.client._command = mock.MagicMock(spec_set=[])
-        root_uuid = 'fake-root-uuid'
-        efi_system_part_uuid = 'fake-efi-system-part-uuid'
         params = {'root_uuid': root_uuid,
-                  'efi_system_part_uuid': efi_system_part_uuid}
+                  'efi_system_part_uuid': efi_system_part_uuid,
+                  'prep_boot_part_uuid': prep_boot_part_uuid}
 
         self.client.install_bootloader(
-            self.node, root_uuid, efi_system_part_uuid=efi_system_part_uuid)
+            self.node, root_uuid, efi_system_part_uuid=efi_system_part_uuid,
+            prep_boot_part_uuid=prep_boot_part_uuid)
         self.client._command.assert_called_once_with(
             node=self.node, method='image.install_bootloader', params=params,
             wait=True)
 
+    def test_install_bootloader(self):
+        self._test_install_bootloader(root_uuid='fake-root-uuid',
+                                      efi_system_part_uuid='fake-efi-uuid')
+
+    def test_install_bootloaderi_with_prep(self):
+        self._test_install_bootloader(root_uuid='fake-root-uuid',
+                                      efi_system_part_uuid='fake-efi-uuid',
+                                      prep_boot_part_uuid='fake-prep-uuid')
+
     def test_get_clean_steps(self):
         self.client._command = mock.MagicMock(spec_set=[])
         ports = []
@@ -304,3 +346,79 @@ class TestAgentClient(base.TestCase):
                           self.client.finalize_rescue,
                           self.node)
         self.assertFalse(self.client._command.called)
+
+
+class TestAgentClientAttempts(base.TestCase):
+    def setUp(self):
+        super(TestAgentClientAttempts, self).setUp()
+        self.client = agent_client.AgentClient()
+        self.client.session = mock.MagicMock(autospec=requests.Session)
+        self.node = MockNode()
+
+    @mock.patch.object(retrying.time, 'sleep', autospec=True)
+    def test__command_fail_all_attempts(self, mock_sleep):
+        mock_sleep.return_value = None
+        error = 'Connection Timeout'
+        method = 'standby.run_image'
+        image_info = {'image_id': 'test_image'}
+        params = {'image_info': image_info}
+        self.client.session.post.side_effect = [requests.Timeout(error),
+                                                requests.Timeout(error),
+                                                requests.Timeout(error),
+                                                requests.Timeout(error)]
+        self.client._get_command_url(self.node)
+        self.client._get_command_body(method, params)
+
+        e = self.assertRaises(exception.AgentConnectionFailed,
+                              self.client._command,
+                              self.node, method, params)
+        self.assertEqual('Connection to agent failed: Failed to connect to '
+                         'the agent running on node %(node)s for invoking '
+                         'command %(method)s. Error: %(error)s' %
+                         {'method': method, 'node': self.node.uuid,
+                          'error': error}, str(e))
+        self.assertEqual(3, self.client.session.post.call_count)
+
+    @mock.patch.object(retrying.time, 'sleep', autospec=True)
+    def test__command_succeed_after_two_timeouts(self, mock_sleep):
+        mock_sleep.return_value = None
+        error = 'Connection Timeout'
+        response_data = {'status': 'ok'}
+        response_text = json.dumps(response_data)
+        method = 'standby.run_image'
+        image_info = {'image_id': 'test_image'}
+        params = {'image_info': image_info}
+        self.client.session.post.side_effect = [requests.Timeout(error),
+                                                requests.Timeout(error),
+                                                MockResponse(response_text)]
+
+        response = self.client._command(self.node, method, params)
+        self.assertEqual(3, self.client.session.post.call_count)
+        self.assertEqual(response, response_data)
+        self.client.session.post.assert_called_with(
+            self.client._get_command_url(self.node),
+            data=self.client._get_command_body(method, params),
+            params={'wait': 'false'},
+            timeout=60)
+
+    @mock.patch.object(retrying.time, 'sleep', autospec=True)
+    def test__command_succeed_after_one_timeout(self, mock_sleep):
+        mock_sleep.return_value = None
+        error = 'Connection Timeout'
+        response_data = {'status': 'ok'}
+        response_text = json.dumps(response_data)
+        method = 'standby.run_image'
+        image_info = {'image_id': 'test_image'}
+        params = {'image_info': image_info}
+        self.client.session.post.side_effect = [requests.Timeout(error),
+                                                MockResponse(response_text),
+                                                requests.Timeout(error)]
+
+        response = self.client._command(self.node, method, params)
+        self.assertEqual(2, self.client.session.post.call_count)
+        self.assertEqual(response, response_data)
+        self.client.session.post.assert_called_with(
+            self.client._get_command_url(self.node),
+            data=self.client._get_command_body(method, params),
+            params={'wait': 'false'},
+            timeout=60)
